# Datasets

Functions for loading motif collections, annotations, and example datasets.

```{eval-rst}
.. currentmodule:: tfmindi

.. autosummary::
    :toctree: ../generated

    fetch_motif_collection
    fetch_motif_annotations
    load_motif_collection
    load_motif_annotations
    load_motif_to_dbd
```
